@@ -24,6 +24,8 @@ from gensim import matutils
 
 module_path = os.path.dirname(__file__) # needed because sample data files are located in the same folder
 
+logging.basicConfig(format = '%(asctime)s : %(levelname)s : %(message)s', level = logging.WARNING)
+
 
 def testfile():
     # temporary data will be stored to this file
@@ -45,7 +47,6 @@ class TestLsiModel(unittest.TestCase):
         
         expected = numpy.array([-0.6594664, 0.142115444]) # scaled LSI version
         # expected = numpy.array([-0.1973928, 0.05591352]) # non-scaled LSI version
-        
         self.assertTrue(numpy.allclose(abs(vec), abs(expected))) # transformed entries must be equal up to sign
     
     
@@ -55,10 +56,11 @@ class TestLsiModel(unittest.TestCase):
         
         # create the transformation model
         model2 = lsimodel.LsiModel(corpus = corpus, numTopics = 5) # compute everything at once
-        model = lsimodel.LsiModel(corpus = None, id2word = model2.id2word, numTopics = 5, extraDims = 2) # start with no documents, we will add then later
+        model = lsimodel.LsiModel(corpus = None, id2word = model2.id2word, numTopics = 5) # start with no documents, we will add then later
         
         # train model on a single document
         model.addDocuments([corpus[0]])
+        model.printDebug()
         
         # transform the testing document with this partial transformation
         transformed = model[doc]
@@ -68,15 +70,18 @@ class TestLsiModel(unittest.TestCase):
         
         # train on another 4 documents
         model.addDocuments(corpus[1:5], chunks = 2) # train in chunks of 2 documents, for the lols
+        model.printDebug()
         
         # transform a document with this partial transformation
         transformed = model[doc]
         vec = matutils.sparse2full(transformed, model.numTopics) # convert to dense vector, for easier equality tests
         expected = numpy.array([-0.66493785, -0.28314203, -1.56376302,  0.05488682,  0.17123269]) # scaled LSI version
+        m2 = lsimodel.LsiModel(corpus = list(corpus)[:5], numTopics = 5)
         self.assertTrue(numpy.allclose(abs(vec), abs(expected), atol = 1e-6)) # transformed entries must be equal up to sign
         
         # train on the rest of documents
         model.addDocuments(corpus[5:])
+        model.printDebug()
         
         # make sure the final transformation is the same as if we had decomposed the whole corpus at once
         vec1 = matutils.sparse2full(model[doc], model.numTopics)
@@ -89,7 +94,8 @@ class TestLsiModel(unittest.TestCase):
         model.save(testfile())
         model2 = lsimodel.LsiModel.load(testfile())
         self.assertEqual(model.numTopics, model2.numTopics)
-        self.assertTrue(numpy.allclose(model.projection, model2.projection))
+        self.assertTrue(numpy.allclose(model.projection.u, model2.projection.u))
+        self.assertTrue(numpy.allclose(model.projection.s, model2.projection.s))
 #endclass TestLsiModel
 
 
@@ -177,5 +183,5 @@ class TestTfidfModel(unittest.TestCase):
 
 
 if __name__ == '__main__':
-    logging.basicConfig(level = logging.WARNING)
+    logging.root.setLevel(logging.WARNING)
     unittest.main()
